ColoringGreedy

Enum ColoringGreedy 

pub enum ColoringGreedy {
    ColoredNeighbors,
    DSatur,
}
Vertex ordering heuristic of Graph::vertex_coloring_greedy (igraph_coloring_greedy_t).

Variants



ColoredNeighbors

Start from a vertex of maximum degree, then color next the vertex with the largest number of already colored neighbors (IGRAPH_COLORING_GREEDY_COLORED_NEIGHBORS). Both counts include multi-edges with their multiplicity.



DSatur

Color next the vertex with the largest number of distinct colors in its neighborhood (its saturation degree), breaking ties by the number of uncolored neighbors (IGRAPH_COLORING_GREEDY_DSATUR). This is Brélaz’s DSatur heuristic (Commun. ACM 22(4), 1979, https://doi.org/10.1145/359094.359101); it is exact on bipartite graphs, cycles and wheels.